# terminal temple

The long-awaited sequel to [terminal_quest](https://bitbucket.org/bubioinformaticshub/terminal_quest).
This is a slightly less cute little set of puzzles that develops slightly more
advanced command line skills than terminal_quest. It requires python 3.6 or
greater.

**Note:** to complete these puzzles, you should have a firm grasp of these
shell commands:

* *cd*
* *mv*
* *cat*
* *find*
* *echo*
* *export* and environment variables

A command line text editor might be helpful as well.


You can install it with

```
pip install terminal-temple
```

Once installed, the command line commaned `terminal_temple` will be available
on your command line. Run it to start the puzzles!
